@@ -3,22 +3,19 @@
 # @Author: caktux
 # @Date:   2014-12-21 12:44:20
 # @Last Modified by:   caktux
-# @Last Modified time: 2015-01-06 22:08:20
+# @Last Modified time: 2015-02-18 02:02:31
 
 import os
-import json
-import shutil
 import config as c
 import logging
 import logging.config
-from deploy import *
-logger = logging.getLogger(__name__)
-
+import deploy
 from utils import config_dir, configure_logging
 from argparse import ArgumentParser
-
 from . import __version__
 
+logger = logging.getLogger(__name__)
+
 def parse_arguments(parser):
     parser.add_argument(
         "-r", "--host",
@@ -90,9 +87,7 @@ def main():
     config = create_config(parser)
 
     # Logging
-    configure_logging(config.get('misc', 'logging') or '',
-
-    verbosity=config.getint('misc', 'verbosity'))
+    configure_logging(config.get('misc', 'logging') or '', verbosity=config.getint('misc', 'verbosity'))
     logger.info('PyEPM %s', __version__)
     logger.info('=====')
 
@@ -105,7 +100,8 @@ def main():
             logger.warn("File does not exist: %s" % filename)
         else:
             logger.info("Deploying %s..." % filename)
-            deploy(filename)
+            deployment = deploy.Deploy(filename, config)
+            deployment.deploy()
 
 
 if __name__ == '__main__':
